@@ -2,18 +2,14 @@ from typing import Dict
 
 from nbformat import NotebookNode, v4
 
-from jupyter_scheduler.models import ParameterValues
 from jupyter_scheduler.utils import find_cell_index_with_tag
 
 
-def add_parameters(nb: NotebookNode, parameters: Dict[str, ParameterValues]) -> NotebookNode:
+def add_parameters(nb: NotebookNode, parameters: Dict[str, str]) -> NotebookNode:
     content = []
 
     for key, value in parameters.items():
-        if type(value) == str:
-            content.append(f"{key} = '{value}'")
-        else:
-            content.append(f"{key} = {value}")
+        content.append(f"{key} = {value}")
 
     new_cell = v4.new_code_cell(source="\n".join(content))
     new_cell.metadata["tags"] = ["injected-parameters"]
